# rawphoto

[![Build Status](https://travis-ci.org/SamWhited/rawphoto.svg)](https://travis-ci.org/SamWhited/rawphoto)
[![Coverage Status](https://img.shields.io/coveralls/SamWhited/rawphoto.svg)](https://coveralls.io/r/SamWhited/rawphoto)

This package facilitates the parsing of raw photo formats in Python.

Supported formats include:

  - Canon CR2

## Installing

Using pip:

    $ pip install rawphoto
